public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
From: Florian Fainelli <f.fainelli@gmail.com>
To: linux-kernel@vger.kernel.org
Cc: torvalds@linux-foundation.org,
	Florian Fainelli <f.fainelli@gmail.com>,
	Tomohiro Kusumi <tkusumi@tuxera.com>,
	Andrew Morton <akpm@linux-foundation.org>,
	Ian Kent <raven@themaw.net>, Ingo Molnar <mingo@kernel.org>
Subject: [PATCH] autofs: Revert wait_queue_t => wait_queue_entry_t rename
Date: Sun,  9 Jul 2017 21:40:15 -0700	[thread overview]
Message-ID: <20170710044018.12474-1-f.fainelli@gmail.com> (raw)
In-Reply-To: <90ca2c9c-5b48-44f2-a590-ae4e42a61376@gmail.com>

This reverts commit ac6424b981bce1c4bc55675c6ce11bfe1bbfa64f "("sched/wait:
Rename wait_queue_t => wait_queue_entry_t") as far as the autofs user API
structures are concerned since that would break user space build against such
kernel headers.

Fixes: ac6424b981bc ("sched/wait: Rename wait_queue_t => wait_queue_entry_t")
Signed-off-by: Florian Fainelli <f.fainelli@gmail.com>
---
 include/uapi/linux/auto_fs.h  | 4 ++--
 include/uapi/linux/auto_fs4.h | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/include/uapi/linux/auto_fs4.h b/include/uapi/linux/auto_fs4.h
index 65b72d0222e7..7c6da423d54e 100644
--- a/include/uapi/linux/auto_fs4.h
+++ b/include/uapi/linux/auto_fs4.h
@@ -108,7 +108,7 @@ enum autofs_notify {
 /* v4 multi expire (via pipe) */
 struct autofs_packet_expire_multi {
 	struct autofs_packet_hdr hdr;
-	autofs_wqt_t wait_queue_entry_token;
+	autofs_wqt_t wait_queue_token;
 	int len;
 	char name[NAME_MAX+1];
 };
@@ -123,7 +123,7 @@ union autofs_packet_union {
 /* autofs v5 common packet struct */
 struct autofs_v5_packet {
 	struct autofs_packet_hdr hdr;
-	autofs_wqt_t wait_queue_entry_token;
+	autofs_wqt_t wait_queue_token;
 	__u32 dev;
 	__u64 ino;
 	__u32 uid;
diff --git a/include/uapi/linux/auto_fs.h b/include/uapi/linux/auto_fs.h
index 1953f8d6063b..aa63451ef20a 100644
--- a/include/uapi/linux/auto_fs.h
+++ b/include/uapi/linux/auto_fs.h
@@ -26,7 +26,7 @@
 #define AUTOFS_MIN_PROTO_VERSION	AUTOFS_PROTO_VERSION
 
 /*
  * The wait_queue_entry_token (autofs_wqt_t) is part of a structure which is passed
  * back to the kernel via ioctl from userspace. On architectures where 32- and
  * 64-bit userspace binaries can be executed it's important that the size of
  * autofs_wqt_t stays constant between 32- and 64-bit Linux kernels so that we
@@ -49,7 +49,7 @@ struct autofs_packet_hdr {
 
 struct autofs_packet_missing {
 	struct autofs_packet_hdr hdr;
-	autofs_wqt_t wait_queue_entry_token;
+	autofs_wqt_t wait_queue_token;
 	int len;
 	char name[NAME_MAX+1];
 };	
@@ -26,7 +26,7 @@
 
 /*
- * The wait_queue_entry_token (autofs_wqt_t) is part of a structure which is passed
+ * The wait_queue_token (autofs_wqt_t) is part of a structure which is passed
  * back to the kernel via ioctl from userspace. On architectures where 32- and
  * 64-bit userspace binaries can be executed it's important that the size of
-- 
2.11.0

  reply	other threads:[~2017-07-10  4:40 UTC|newest]

Thread overview: 11+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2017-07-03  8:39 [GIT PULL] scheduler changes for v4.13 Ingo Molnar
2017-07-10  4:19 ` Florian Fainelli
2017-07-10  4:40   ` Florian Fainelli [this message]
2017-07-10  8:45     ` [PATCH] autofs: Revert wait_queue_t => wait_queue_entry_t rename Ingo Molnar
2017-07-10  8:52     ` kbuild test robot
2017-07-10  9:42     ` kbuild test robot
2017-07-10 14:01     ` Gabriel C
2017-07-10 15:52       ` Florian Fainelli
2017-07-10 18:47       ` Linus Torvalds
2017-07-10 23:00         ` Florian Fainelli
2017-07-10  8:45   ` [GIT PULL] scheduler changes for v4.13 Ingo Molnar

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20170710044018.12474-1-f.fainelli@gmail.com \
    --to=f.fainelli@gmail.com \
    --cc=akpm@linux-foundation.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=mingo@kernel.org \
    --cc=raven@themaw.net \
    --cc=tkusumi@tuxera.com \
    --cc=torvalds@linux-foundation.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox